package tech.mercantec.easyeat.ui.dishes

import android.app.Activity
import android.content.Intent
import android.os.Bundle
import android.util.Log
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.Button
import android.widget.Toast
import androidx.activity.result.ActivityResultLauncher
import androidx.activity.result.contract.ActivityResultContracts
import androidx.fragment.app.Fragment
import androidx.lifecycle.lifecycleScope
import kotlinx.coroutines.launch
import tech.mercantec.easyeat.R
import tech.mercantec.easyeat.databinding.FragmentDishesBinding
import tech.mercantec.easyeat.helpers.ApiRequestException
import tech.mercantec.easyeat.helpers.RecipeResponse
import tech.mercantec.easyeat.helpers.getRecipies
import tech.mercantec.easyeat.helpers.login
import tech.mercantec.easyeat.models.DishListItem
import tech.mercantec.easyeat.ui.MainActivity
import kotlin.concurrent.thread

class DishesFragment : Fragment() {

    private var _binding: FragmentDishesBinding? = null
    private lateinit var createDishLauncher: ActivityResultLauncher<Intent>
    private val binding get() = _binding!!

    override fun onCreateView(
        inflater: LayoutInflater,
        container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {
        _binding = FragmentDishesBinding.inflate(inflater, container, false)
        val root: View = binding.root

        loadRecipes()

        binding.addDish.setOnClickListener {
            val dialogView = LayoutInflater.from(requireContext()).inflate(R.layout.create_dish_modal_dialog, null)

            val dialog = android.app.AlertDialog.Builder(requireContext())
                .setView(dialogView)
                .setCancelable(true) // tap outside to dismiss
                .create()

            dialog.window?.setBackgroundDrawableResource(android.R.color.transparent)

            dialogView.findViewById<Button>(R.id.createManualBtn).setOnClickListener {
                val intent = Intent(requireContext(), CreateDishActivity::class.java)
                createDishLauncher.launch(intent)
                dialog.dismiss()
            }

            dialogView.findViewById<Button>(R.id.createAIBtn).setOnClickListener {
                val intent = Intent(requireContext(), CreateDishAIActivity::class.java)
                createDishLauncher.launch(intent)
                dialog.dismiss()
            }

            dialog.show()
        }


        return root

    }
     fun DishesFragment.loadRecipes() {
        thread {
            val recipes: List<RecipeResponse>
            try {
                recipes = getRecipies(requireContext())
            } catch (e: ApiRequestException) {
                activity?.runOnUiThread {
                    Toast.makeText(requireContext(), e.message, Toast.LENGTH_LONG).show()
                }
                return@thread
            }

            val dishes = recipes.map {
                DishListItem(it.id, it.name, it.description)
            }

            activity?.runOnUiThread {
                val adapter = DishAdapter(requireContext(), dishes)
                binding.dishesList.adapter = adapter
            }
        }
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)

        createDishLauncher = registerForActivityResult(ActivityResultContracts.StartActivityForResult()) { result ->
            if (result.resultCode == Activity.RESULT_OK) {
                loadRecipes()
            }
        }
    }

    override fun onDestroyView() {
        super.onDestroyView()
        _binding = null
    }
}
